#!/usr/bin/env python
# -*- coding: utf-8 -*-
files=["../MAC_APP_STORE_METADATA", "../iOS_APP_STORE_METADATA", "../CHANGELOG", "../iOS_CHANGELOG"]
files=[(x, open(x, "r").readlines()) for x in files]
for f in files:
	f = [f[0],[[x+1,f[1][x]] for x in range(len(f[1]))]]
	for line in f[1]:
		if line[1].strip():
			print('#: ' + f[0] + ':' + str(line[0]))
			print('msgid "' + line[1].strip(' * ').strip().replace('"','\\"') + '"')
			print('msgstr ""\n')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -> htmhtm - the synched .htm file viewing utility
# -> To run this you will require wxPython.
# -> Put the name of the htm or html files you want to compare in the LeftView and RightView variables.
# -> The right scrollbars effect only their window, the left scrollbars effect both windows.

LeftView = "/home/david/Documents/pots/it.po.html"
RightView = "/home/david/Documents/pots/pt_BR.po.html"



import wx
import  wx.html as  html

class MySplitter(wx.SplitterWindow):
	def __init__(self, parent, ID):
		wx.SplitterWindow.__init__(self, parent, ID,
								   style = wx.SP_LIVE_UPDATE
								   )
		
		self.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGED, self.OnSashChanged)
		self.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGING, self.OnSashChanging)

	def OnSashChanged(self, evt):
		#print "sash changed to %s" % str(evt.GetSashPosition())
		pass

	def OnSashChanging(self, evt):
		#print "sash changing to %s" % str(evt.GetSashPosition())
		# uncomment this to not allow the change
		#evt.SetSashPosition(-1)
		pass
	
		
		
# This shows how to catch the OnLinkClicked non-event.  (It's a virtual
# method in the C++ code...)
class MyHtmlWindow(html.HtmlWindow):
	def __init__(self, parent, id):
		html.HtmlWindow.__init__(self, parent, id, style=wx.NO_FULL_REPAINT_ON_RESIZE)
		if "gtk2" in wx.PlatformInfo:
			self.SetStandardFonts()
		
		self.Bind(wx.EVT_SCROLLWIN, self.OnScroll)
		
	def OnScroll(self, evt):
		#print "scroll " + str(evt.GetPosition())
		if(evt.GetOrientation() == 8):
			self.Scroll(self.GetViewStart()[0], evt.GetPosition())
		else:
			self.Scroll(evt.GetPosition(), self.GetViewStart()[1])
			
	def SetSynch(self, target):
		print "set target " + str(target)
		self.synch = target
		
class MyHtmlSynchWindow(html.HtmlWindow):
	def __init__(self, parent, id):
		html.HtmlWindow.__init__(self, parent, id, style=wx.NO_FULL_REPAINT_ON_RESIZE)
		if "gtk2" in wx.PlatformInfo:
			self.SetStandardFonts()
		
		self.Bind(wx.EVT_SCROLLWIN, self.OnScroll)
		
	def OnScroll(self, evt):
		#print "scroll " + str(evt.GetPosition())
		if(evt.GetOrientation() == 8):
			delta = self.GetViewStart()[1] - evt.GetPosition()
			self.Scroll(self.GetViewStart()[0], self.GetViewStart()[1]-delta)
			self.synch.Scroll(self.synch.GetViewStart()[0], self.synch.GetViewStart()[1]-delta)
		else:
			delta = self.GetViewStart()[0] - evt.GetPosition()
			self.Scroll(self.GetViewStart()[0]-delta, self.GetViewStart()[1])
			self.synch.Scroll(self.synch.GetViewStart()[0]-delta, self.synch.GetViewStart()[1])
			
	def SetSynch(self, target):
		print "set target " + str(target)
		self.synch = target


class Example(wx.Frame):
	def __init__(self, parent, title):
		super(Example, self).__init__(parent, title=title, 
			size=(1200, 800))
			
		self.InitUI()
		self.Show()	 
		
	def InitUI(self):
		splitter = MySplitter(self, -1)
		sty = wx.BORDER_SUNKEN
		

		p1 = wx.Panel(splitter, style=sty)
		p1.SetBackgroundColour("pink")
		#wx.StaticText(p1, -1, "Panel One", (5,5))

		p2 = wx.Panel(splitter, style=sty)
		p2.SetBackgroundColour("sky blue")
		wx.StaticText(p2, -1, "Panel Two", (5,5))
		
		self.html = MyHtmlSynchWindow(p1, 10)
		self.html.LoadPage(LeftView)

		self.box1 = wx.BoxSizer(wx.VERTICAL)
		self.box1.Add(self.html, 1, wx.EXPAND | wx.ALL, 2)
		p1.SetSizer(self.box1)
		
		self.html_ = MyHtmlWindow(p2, 11)
		self.html_.LoadPage(RightView)

		self.box2 = wx.BoxSizer(wx.VERTICAL)
		self.box2.Add(self.html_, 1, wx.EXPAND | wx.ALL, 2)
		p2.SetSizer(self.box2)
		
		self.html.SetSynch(self.html_)
		self.html_.SetSynch(self.html)
		
		splitter.SetMinimumPaneSize(500)
		splitter.SplitVertically(p1, p2, -100)
		
		


if __name__ == '__main__':
  
	app = wx.App()
	Example(None, title='HtmHtm')
	app.MainLoop()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os, sys, codecs
#usage: from frogatto's base folder, run:
#utils/text_width_check.py po/(desired file, with a "po" or "pot" extension) [optional:max width]
#e.g.:
#utils/text_width_check.py po/frogatto.pot 360
global MAXWIDTH
MAXWIDTH = 360

def main(catalog):
	if catalog.split('.')[-1] == "pot":
		check = "msgid"
		font = "dialog_font.cfg"
	elif catalog.split('.')[-1] == "po":
		check = "msgstr"
		#look for a specific dialog_font definition for that locale;
		#if unavailable, select the default one
		font = "dialog_font." + catalog.split('.')[0].split('/')[1] + ".cfg"
		if font not in os.listdir('data'):
			font = "dialog_font.cfg"
	else: return
	
	fontdata = codecs.open("../../data/" + font, encoding="utf-8").readlines()
	fontdata = [x.strip() for x in fontdata]
	charwidths = {}
	i = 0
	#default kerning for fonts
	kerning = 2
	while i < len(fontdata):
		if "kerning:" in fontdata[i]:
			kerning = int(fontdata[i].split(":")[1].replace(',',''))
		if "chars: \"" in fontdata[i]:
			chars = list(fontdata[i].split(":", 1)[1].replace(" \"", "",1).replace("\",", "",1))
		elif "width:" in fontdata[i]:
			for x in chars:
				charwidths[x]=int(fontdata[i].split(":")[1].replace(',',''))
		elif "rect:" in fontdata[i]:
			width = fontdata[i].replace('[','').replace(']','').split(':')[1].split(',')[:-1]
			width = int(width[2]) - int(width[0]) + 1
			for x in chars:
				charwidths[x]=width
		i += 1
	
	f = codecs.open(catalog, encoding="utf-8").readlines()
	#start from the first message line, i. e., the first with a #:
	l = [x[:2] for x in f].index("#:")
	msgline = 0
	while l < len(f):
		if "#:" in f[l] and "#:" not in f[l-1]:
			msgline = l
		if check in f[l]:
			linewidth = checkwidth(getmessage(f[l]), charwidths, kerning)
			if linewidth > MAXWIDTH:
				printline(f, msgline, linewidth)
			if len(getmessage(f[l])) == 0:
				l += 1
				while l < len(f) and '"' in f[l] and f[l][0] != "m":
					linewidth = checkwidth(getmessage(f[l]), charwidths, kerning)
					if linewidth > MAXWIDTH:
						printline(f, msgline, linewidth)
					l += 1
		l += 1
		
def printline(f, start, width):
	line = start
	sys.stdout.write((str(width) + " pixels:\n").encode("utf-8"))
	while len(f[line].strip()) > 0:
		sys.stdout.write((f[line].strip()+"\n").encode("utf-8"))
		line += 1
	sys.stdout.write("\n".encode("utf-8"))
	
def checkwidth(line, widths, kerning):
	result = 0
	for x in line:
		if x in widths.keys():
			result += widths[x] + kerning
	return result - kerning
			
def getmessage(line):
	if line[0] == "m":
		return line.replace('\\n','').replace('\r','').replace('\n','').split(' ',1)[1][1:-1]
	else:
		return line.replace('\\n','').replace('\r','').replace('\n','')[1:-1]
	
if __name__ == "__main__":
	if len(sys.argv) == 2:
		main(sys.argv[1])
	elif len(sys.argv) == 3:
		MAXWIDTH = int(sys.argv[2])
		main(sys.argv[1])
	else:
		pass




import sys

def main(f):
	tiles = open(f, 'r').readlines()
	tiles = "".join(tiles).replace("\n","")
	tiles = "".join(['{0},'.format(x) for x in tiles])[:-1]
	tiles = "land = [" + tiles + "]"
	print tiles

if __name__ == "__main__":
	if len(sys.argv) == 2:
		main(sys.argv[1])
		



#!/usr/bin/env python
# -*- coding: utf-8 -*-

print "TrainGen - The mass [animation] generator for Cube Trains.\nOutput:\n\n\n	#generated with ct-traingen utility.#"

for a in range(36):
	print """	[animation]
		id=normal-{0}
		image=experimental/cube trains/{1:0>4}.png
		rect=105,128,155,178
	[/animation]""".format(a, a+41)


print "\n\nEnd output."



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""args: <file to analyze> <optional int quality>
Plots player's position points. Requires matplotlib for output.
See end of file for more details."""

from matplotlib.pylab import *
from math import *
import re
import sys


# \[.+\]			->				removes tags
# .*src.*|.*ms.*	->				removes non-dst lines
# dst="(.*)"		->	[\1],		formats dsts to square-bracketed list
# \s|\n				->				removes whitespace
# (.*)				->	[\1]		make it a list

def main(rawFile, radius):
	border = [10,10]
	
	radius = int(radius)
	points = []
	
	shortFileName = "output"
	parseName = re.match(r".*/(.*).cfg", rawFile)
	if parseName is not None:
		shortFileName = parseName.group(1)
	else:
		print "Error parsing " + rawFile

	print "reading data",
	sys.stdout.flush()
	dot = 0
	for line in open(rawFile, 'r').readlines():
		dst = re.match(r".*dst=\"([0-9|-]*),([0-9|-]*)", line)
		dot += 1
		if dot %100000 == 0:
			print "\b.",
			sys.stdout.flush()
		if dst and dst.group(2):
			points.append([int(dst.group(1)), int(dst.group(2))])
	print ""

	def samplemat(dims, points, offset):
		"""Write points into dims."""
		ptSize = radius
		pts = len(points)
		aa = zeros(dims)
		percentage = 0
		for i in range(pts):
			pt = [points[i][0]+offset[0], points[i][1]+offset[1]]
			newPercent = round((i+1.0)/pts, 3)*100
			if percentage != newPercent:
				percentage = newPercent
				print "  Mapping point " + str(i+1) + " of " + str(pts) + ". (" + str(percentage) + "%)"
			for x in range(ptSize):
				tX = pt[0]+x-ptSize/2
				for y in range(ptSize):
					tY = pt[1]+y-ptSize/2
					#print "plotting against the goverment at: " + str([tX, tY])
					if 0 <= tX < dims[0] and 0 <= tY < dims[1] :
						aa[tX,tY] = floor(aa[tX, tY] + ceil(ptSize/2-math.hypot(tX-pt[0], tY-pt[1]), 0), 400)
						
		print "Scaling colours."
		sys.stdout.flush()
		newMap = zeros(dims)
		for x in range(len(aa)):
			for y in range(len(aa[x])):
				newMap[x,y] = math.pow(aa[x,y], 0.5)
		return newMap
		
	def ceil(a, b):
		if a >= b:
			return a
		return b	
	def floor(a, b):
		if a <= b:
			return a
		return b

	def strip(array, index):
		newList = []
		for element in array:
			newList.append(element[index])
		return newList
		
	def normaliseArray(mins, array):
		newList = []
		for element in array:
			newList.append([element[1] - mins[1], element[0] - mins[0]])
		return newList

	print "Calculating size."
	maxPoints = [max(strip(points, 0)), max(strip(points, 1))]
	minPoints = [min(strip(points, 0)), min(strip(points, 1))]
	size = [maxPoints[1] - minPoints[1] + border[1], maxPoints[0] - minPoints[0] + border[0]]
	print "Normalising all data."
	points = normaliseArray(minPoints, points)

	print "Rendering."
	fig = plt.figure()
	matshow(samplemat(size, points, [border[0]/2, border[1]/2]), fignum=0, interpolation='bicubic', cmap=cm.gist_heat)
	print "Postprocessing."
	sys.stdout.flush()
	fig.canvas.set_window_title('Matrix-Heat : ' + shortFileName)
	saveName = "mh-" + shortFileName + ".png"
	savefig(saveName, dpi=720)
	print "Done, saved file as " + saveName
	
	#show()		#the interactive gui

if __name__ == "__main__":
	if len(sys.argv) == 2:
		main(sys.argv[1], 10)
	elif len(sys.argv) == 3:
		main(sys.argv[1], sys.argv[2])
	else:
		print """
== Matrix-Heat Quick Guide ==

Run: python matrix-heat.py string Relative_File [optional int Quality]
Relative_File: This is a path to the Frogatto statistics .cfg file to analyze.
Quality: How big of a brush to use. The bigger the brush, the longer it takes to draw a data point. Defaults to 10. Minimum is 5. It probaby doesn't need to be set larger than 25.

Notes:
This utility requires matplotlib to run, in addition to Python. You can download the stats files from http://wesnoth.org/files/dave/frogatto-stats/. You can change the palette by changing the cmap variable in the matshow function to these: http://www.scipy.org/Cookbook/Matplotlib/Show_colormaps. Uncomment 'show()' to enable the interactive GUI. For further details, write to http://www.frogatto.com/forum/index.php. Have a nice day. :)"""
		


import string
def main(text_in):
	text_size = len(text_in)
	pos = 0 #start at the beginning of the text
	text_in += '\n    ' #bit of padding for the end.
	mode = 'normal'
	
	print (' == START OF TRANSLATION == \n\n')
	
	if text_in[pos:pos+5] == '#summ':
		while text_in[pos] != '\n':
			pos +=1
	
	while pos < text_size:
		
		if text_in[pos:pos+2] == '[[': #links
			pos += 2
			start = pos
			while text_in[pos:pos+2] != ']]':
				pos +=1
			parts = (text_in[start:pos].split('|'))
			if len(parts) == 1:
				print('[[' + parts[0] + ']]', end='')
			else:
				print('[' + parts[0] + '](' + parts[1] + ')', end='')
			pos += 2
			
		elif text_in[pos:pos+5] == '\n{{{\n': #code blocks
			pos += 4
			while text_in[pos:pos+4] != '\n}}}':
				if text_in[pos] == '\n':
					pos +=1
					print('\n    ', end='')
				print(text_in[pos], end='')
				pos += 1
			pos += 4
			
		elif text_in[pos:pos+3] == '{{{': #code blocks
			pos += 3
			print ('`', end='')
			while text_in[pos:pos+3] != '}}}':
				print(text_in[pos], end='')
				pos += 1
			pos += 3
			print ('`', end='')
			
		elif text_in[pos:pos+2] == '{{': #images
			pos += 2
			start = pos
			while text_in[pos:pos+2] != '}}':
				pos +=1
			parts = (text_in[start:pos].split('|'))
			if len(parts) == 1:
				print('![](' + parts[0] + ')', end='')
			else:
				print('![' + parts[1] + '](' + parts[0] + ')', end='')
			pos += 2
			
		elif text_in[pos:pos+2] == '//': #italics
			pos += 2
			print ('_', end='')
			
		elif mode == 'normal' and text_in[pos:pos+2] == '\n|': #start table
			pos += 2
			mode = 'table header'
			row = 0
			print ('\n<table>\n  <tr>\n    <th>', end='')
		
		elif mode == 'table header' and (text_in[pos:pos+2] == '|\n' or text_in[pos] == '\n'): #newline from table header row
			pos += 3
			mode = 'table'
			print('</th>\n  </tr>\n  <tr>\n    <td>', end='')
		
		elif mode == 'table' and (text_in[pos:pos+2] == '|\n' or text_in[pos] == '\n'): #newline from table row
			pos += 2
			if text_in[pos] != '|':
				print('</td>\n  </tr>\n</table>\n', end='')
			else:
				pos += 1
				print('</td>\n  </tr>\n  <tr>\n    <td>', end='')
			mode = 'normal'
		
		elif mode == 'table header' and text_in[pos] == '|': #next table header column
			pos += 1
			print('</th><th>', end='')
		
		elif mode == 'table' and text_in[pos] == '|': #next table column
			pos += 1
			print('</td><td>', end='')
		
		elif text_in[pos:pos+2] == '\n=' or text_in[pos:pos+3] == '\n =': #header detection -- a little shoddy, only checks leading =.
			pos += 1
			headcount = 0
			while text_in[pos] == '=' or text_in[pos] == ' ':
				if text_in[pos] == '=':
					headcount += 1
				pos +=1
			headcounter = headcount
			while headcounter > 0:
				print('#', end='')
				headcounter -=1
			print(end=' ')
			while text_in[pos] != '=' and text_in[pos] != '\n':
				print(text_in[pos], end='')
				pos += 1
			pos += headcount
			
		else: #must be just text, print it normally
			print(text_in[pos], end='')
			pos += 1
			
	print('\n')
	
if __name__ == "__main__":
	main("""
<< PASTE WIKI PAGE HERE >>
""")


from __future__ import print_function
import urllib
from HTMLParser import HTMLParser
stats_upload_url = "http://www.wesnoth.org/files/dave/frogatto-stats-1.1.1/"

class FrogattoStatsFilenames(HTMLParser):
	stats_files = []
	
	def __init__(self):
		HTMLParser.__init__(self)
		self.feed(urllib.urlopen(stats_upload_url).read())
		
	def handle_starttag(self, tag, attrs):
		if(attrs and attrs[0][0] == 'href') and attrs[0][1].endswith('.cfg'):
			#print("tag/attrs: ", tag, attrs)
			self.stats_files.append(attrs[0][1])
			
print("Downloading filenames...")
parse = FrogattoStatsFilenames()
print("Saving {0} filenames...".format(len(parse.stats_files)))
name_file = open("list of frogatto stats files.txt", 'w', 0)
print(parse.stats_files, file=name_file)
print("Done.")